#!/bin/bash

INPUT=$*
if [ "$INPUT" == "--test" ]; then
   TEST=1
elif [ "$INPUT" == "--flash" ]; then
   TEST=0  
elif [ "$INPUT" == "--help" ]; then
   echo ""
   echo "Update hardware Secure Boot DBX database with forbidden hashes/keys from HPE"
   echo ""
   echo "'$0' will update the hardware DBX Secure Boot variable to include"
   echo "forbidden hashes and keys from HPE.  Older boot environments from HPE will no"
   echo "longer boot with Secure Boot enabled after the system DBX is updated.  This "
   echo "includes old versions of the Intelligent Provisioning ROM, the Service Pack for"
   echo "ProLiant boot disc, and the Smart Start Scripting Tool Kit.  Please ensure you"
   echo "have the latest version of each before updating your DBX database"
   echo "with '$0.'  If there are "new keys" on the filesystem during"
   echo "the --test, your system is potentially vulnerable to loading compromised"
   echo "code into the kernel."
   echo ""
   echo "Additional information:  http://downloads.linux.hpe.com/SDR/project/hexane"
   echo ""
   echo "Usage:  $0   [options]"
   echo ""
   echo "  --test  Compare system DBX with hashes provided by this version of $0"
   echo "  --flash Update DBX with hashes/keys found in /usr/share/hpe/secureboot/dbx"
   echo "  --help  More information about HPE DBX updates."
   echo ""
   exit 0
else
   echo ""
   echo "Update hardware Secure Boot DBX database with forbidden hashes/keys from HPE"
   echo ""
   echo "Usage:  $0   [options]"
   echo ""
   echo "  --test  Compare system DBX with hashes provided by this version of $0"
   echo "  --flash Update DBX with hashes/keys found in /usr/share/hpe/secureboot/dbx"
   echo "  --help  More information about HPE DBX updates."
   echo ""
   echo ""
   exit 0
fi

# Get access to efivarfs filesystem, which isn't always mounted
if ! [ -f /sys/firmware/efi/efivars/dbx-d719b2cb-3d3a-4596-a3bc-dad00e67656f ]; then
  # efivarfs isn't always mounted
  modprobe efivarfs
  mount -t efivarfs efivarfs /sys/firmware/efi/efivars
  if ! [ -f /sys/firmware/efi/efivars/dbx-d719b2cb-3d3a-4596-a3bc-dad00e67656f ]; then
     echo "Unable to access /sys/firmware/efi/efivars/dbx-d719b2cb-3d3a-4596-a3bc-dad00e67656f"
     echo "   Are you root?  modprobe efivarfs?  EFI system with Secure Boot?"
     exit 1 
  fi   
fi
  
# efivars are immutable by default, thus chattr
chattr -i /sys/firmware/efi/efivars/dbx-d719b2cb-3d3a-4596-a3bc-dad00e67656f

BINVERSION=/usr/bin/hexane_glibc225  

if [ "$TEST" -eq "1" ]; then
   echo "$BINVERSION --dry-run --verbose --keystore /usr/share/hpe/secureboot/ "
         $BINVERSION --dry-run --verbose --keystore /usr/share/hpe/secureboot/ 
else 
   echo "$BINVERSION           --verbose --keystore /usr/share/hpe/secureboot/ "
         $BINVERSION           --verbose --keystore /usr/share/hpe/secureboot/
fi 


exit 0
